# vs-rgtools

Wrapper for RGVS, RGSF, and various other functions

#### Dependencies

- [vstools](https://github.com/Jaded-Encoding-Thaumaturgy/vstools/)
- [RGVS](https://github.com/vapoursynth/vs-removegrain)
- [RGSF](https://github.com/IFeelBloated/RGSF)
- [Akarin Expr](https://github.com/AkarinVS/vapoursynth-plugin)
